@@ -489,12 +489,12 @@ mlflow_log_artifact <- function(path, artifact_path = NULL, run_id = NULL, clien
   invisible(mlflow_list_artifacts(run_id = run_id, path = artifact_path, client = client))
 }
 
-#' Record logged model metadata with the trackin server.
+# Record logged model metadata with the tracking server.
 mlflow_record_logged_model <- function(model_spec, run_id = NULL, client = NULL) {
   c(client, run_id) %<-% resolve_client_and_run_id(client, run_id)
   mlflow_rest("runs", "log-model", client = client, verb = "POST", data = list(
     run_id = run_id,
-    model_json = toJSON(model_spec, auto_unbox=TRUE)
+    model_json = jsonlite::toJSON(model_spec, auto_unbox=TRUE)
   ))
 }
 
